==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm5/lib/CustomIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends, __values } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { CustomIndicatorStrategy } from "./CustomIndicatorStrategy";
import { String_$type, fromEnum, markType } from "igniteui-react-core";
import { FinancialEventArgs } from "./FinancialEventArgs";
import { List$1 } from "igniteui-react-core";
/**
 * @hidden
 */
var CustomIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CustomIndicator, _super);
    function CustomIndicator() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.zk = null;
        _this.zj = null;
        return _this;
    }
    CustomIndicator.prototype.get_yy = function () {
        return new CustomIndicatorStrategy();
    };
    Object.defineProperty(CustomIndicator.prototype, "yy", {
        get: function () {
            return this.get_yy();
        },
        enumerable: false,
        configurable: true
    });
    CustomIndicator.prototype.get_zb = function () {
        return CustomIndicator.$;
    };
    Object.defineProperty(CustomIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    CustomIndicator.prototype.ya = function (a, b) {
        var e_1, _a;
        var c = this.um(a, b);
        var d = this.un(c);
        var e = new List$1(String_$type, 0);
        if (this.basedOnColumns != null) {
            var f = new FinancialEventArgs(c.calculateFrom, c.calculateCount, c, d, this);
            this.basedOnColumns(this, f);
            if (f.basedOn != null) {
                try {
                    for (var _b = __values(fromEnum(f.basedOn)), _c = _b.next(); !_c.done; _c = _b.next()) {
                        var g = _c.value;
                        e.add(g);
                    }
                }
                catch (e_1_1) {
                    e_1 = { error: e_1_1 };
                }
                finally {
                    try {
                        if (_c && !_c.done && (_a = _b.return))
                            _a.call(_b);
                    }
                    finally {
                        if (e_1)
                            throw e_1.error;
                    }
                }
            }
        }
        return e;
    };
    Object.defineProperty(CustomIndicator.prototype, "indicator", {
        get: function () {
            return this.zk;
        },
        set: function (a) {
            this.zk = a;
            this.yi();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CustomIndicator.prototype, "basedOnColumns", {
        get: function () {
            return this.zj;
        },
        set: function (a) {
            this.zj = a;
        },
        enumerable: false,
        configurable: true
    });
    CustomIndicator.prototype.x7 = function (a, b) {
        _super.prototype.x7.call(this, a, b);
        if (this.indicator != null) {
            var c = this.um(a, b);
            if (b == 0) {
                return false;
            }
            if (!this.vi(this.ya(a, b))) {
                return false;
            }
            this.indicator(this, new FinancialEventArgs(a, b, c, this.un(c), this));
            if (this.y0(c) && this.uv != null) {
                this.uv.c1();
            }
            return true;
        }
        return false;
    };
    CustomIndicator.$t = markType(CustomIndicator, 'CustomIndicator', StrategyBasedIndicator.$);
    return CustomIndicator;
}(StrategyBasedIndicator));
export { CustomIndicator };

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/CustomIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends, __values } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { CustomIndicatorStrategy } from "./CustomIndicatorStrategy";
import { String_$type, fromEnum, markType } from "igniteui-react-core";
import { FinancialEventArgs } from "./FinancialEventArgs";
import { List$1 } from "igniteui-react-core";
/**
 * @hidden
 */
var CustomIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CustomIndicator, _super);
    function CustomIndicator() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.acc = null;
        _this.acb = null;
        return _this;
    }
    CustomIndicator.prototype.bj = function () {
        return new CustomIndicator();
    };
    CustomIndicator.prototype.get_abq = function () {
        return new CustomIndicatorStrategy();
    };
    Object.defineProperty(CustomIndicator.prototype, "abq", {
        get: function () {
            return this.get_abq();
        },
        enumerable: false,
        configurable: true
    });
    CustomIndicator.prototype.get_ab3 = function () {
        return CustomIndicator.$;
    };
    Object.defineProperty(CustomIndicator.prototype, "ab3", {
        get: function () {
            return this.get_ab3();
        },
        enumerable: false,
        configurable: true
    });
    CustomIndicator.prototype.aa2 = function (a, b) {
        var e_1, _a;
        var c = this.xe(a, b);
        var d = this.xf(c);
        var e = new List$1(String_$type, 0);
        if (this.basedOnColumns != null) {
            var f = new FinancialEventArgs(c.calculateFrom, c.calculateCount, c, d, this);
            this.basedOnColumns(this, f);
            if (f.basedOn != null) {
                try {
                    for (var _b = __values(fromEnum(f.basedOn)), _c = _b.next(); !_c.done; _c = _b.next()) {
                        var g = _c.value;
                        e.add(g);
                    }
                }
                catch (e_1_1) {
                    e_1 = { error: e_1_1 };
                }
                finally {
                    try {
                        if (_c && !_c.done && (_a = _b.return))
                            _a.call(_b);
                    }
                    finally {
                        if (e_1)
                            throw e_1.error;
                    }
                }
            }
        }
        return e;
    };
    Object.defineProperty(CustomIndicator.prototype, "indicator", {
        get: function () {
            return this.acc;
        },
        set: function (a) {
            this.acc = a;
            this.aba();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CustomIndicator.prototype, "basedOnColumns", {
        get: function () {
            return this.acb;
        },
        set: function (a) {
            this.acb = a;
        },
        enumerable: false,
        configurable: true
    });
    CustomIndicator.prototype.aaz = function (a, b) {
        _super.prototype.aaz.call(this, a, b);
        if (this.indicator != null) {
            var c = this.xe(a, b);
            if (b == 0) {
                return false;
            }
            if (!this.ya(this.aa2(a, b))) {
                return false;
            }
            this.indicator(this, new FinancialEventArgs(a, b, c, this.xf(c), this));
            if (this.abs(c) && this.xk != null) {
                this.xk.c1();
            }
            return true;
        }
        return false;
    };
    CustomIndicator.$t = markType(CustomIndicator, 'CustomIndicator', StrategyBasedIndicator.$);
    return CustomIndicator;
}(StrategyBasedIndicator));
export { CustomIndicator };
